%% Initialize %%

clear all; close all; clc
maindir = fileparts(mfilename('fullpath'));
lowerPoints = [0 0 0 0 0 0 ];
upperPoints = [5e6 1e12 1e6 1*pi 1e12 10e6 ];

%% Thin Film V1 100W %%

directories = {
    '/data/ThinFilm_V1_100W_0.25Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V1_100W_0.50Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V1_100W_1.00Cf/quarterwave_-60dBm.csv' 
    '/data/ThinFilm_V1_100W_0.25Cf/halfwave_-60dBm.csv'
    '/data/ThinFilm_V1_100W_0.50Cf/halfwave_-60dBm.csv'
    '/data/ThinFilm_V1_100W_1.00Cf/halfwave_-60dBm.csv'
    };

titles_quarter = {
    '0.25 Cf (DCtap 2.375pF)' '0.50 Cf  (DCtap 4.75pF)' '1.00 Cf (DCtap 9.5pF)' 
    };
titles_half = {
    '0.25 Cf' '0.50 Cf' '1.00 Cf' 
    };

for k=1:length(directories)
    dir = [maindir, directories{k}];
    data = dlmread(dir,'',3,0);
    freq = data(:,1);
    amp = sqrt(data(:,2).^2+data(:,3).^2);  % |S21|, amplitude ratio (linear scale)
    [a, b] = max(amp);
    startPoints = [0.1e6 freq(b) 30 0.4*pi max(amp) 1e6   ];
    [fitresult, linewidth] = fanofit(freq,amp,startPoints,lowerPoints,upperPoints);
    if k<4
            figure(1)
            subplot(2,2,k);
            h = plot(fitresult,freq,amp,'o');
            title([titles_quarter(k) linewidth], 'FontSize', 14)
%             sgtitle('Quarterwave Mode ThinFilm V1 100W')
            suptitle('Quarterwave Mode ThinFilm V1 100W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    else 
            figure(2)
            subplot(2,2,k-3);
            h = plot(fitresult,freq,amp,'o');
            title([titles_half(k-3) linewidth], 'FontSize', 14) 
%             sgtitle('Halfwave Mode ThinFilm V1 100W')
            suptitle('Halfwave Mode ThinFilm V1 100W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    end
    xlabel('Frequency (Hz)'); ylabel('|S_{21}|') 
    set(h,'LineWidth',2); set(gca,'YScale','log') % Show |S21| in log scale
    
end

%% Thin Film V2 100W %%

directories = {
    '/data/ThinFilm_V2_100W_0.10Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.25Cf_1/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.25Cf_2/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.50Cf_1/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.50Cf_2/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_1.00Cf_1/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_1.00Cf_2/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.10Cf/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.25Cf_1/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.25Cf_2/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.50Cf_1/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_0.50Cf_2/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_1.00Cf_1/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_100W_1.00Cf_2/halfwave_-60dBm.csv' 
    };

titles_quarter = {
    '0.10 Cf (DCtap 0.5pF)' '0.25 Cf (DCtap 1.25pF)' '0.25 Cf (2)' '0.50 Cf (DCtap 2.5pF)' '0.50 Cf (2)' '1.00 Cf (DCtap 5pF)' '1.00 Cf(2)' 
    };
titles_half = {
    '0.10 Cf' '0.25 Cf' '0.25 Cf (2)' '0.50 Cf' '0.50 Cf (2)' '1.00 Cf' '1.00 Cf(2)' 
    };

for k=1:length(directories)
    dir = [maindir, directories{k}];
    data = dlmread(dir,'',3,0);
    freq = data(:,1);
    amp = data(:,2);  % |S21|, amplitude ratio (linear scale)
    [a, b] = max(amp);
    if k== 10
        startPoints = [0.1e6 freq(b) 30 0.4*pi max(amp) 1e6   ];
    else 
        startPoints = [0.2e6 freq(b) 30 0.4*pi max(amp) 1e6   ];
    end
    [fitresult, linewidth] = fanofit(freq,amp,startPoints,lowerPoints,upperPoints);
    if k<8
            figure(3)
            subplot(2,4,k);
            h = plot(fitresult,freq,amp,'o');
            title([titles_quarter(k) linewidth], 'FontSize', 14) 
%             sgtitle('Quarterwave Mode ThinFilm V2 100W')
            suptitle('Quarterwave Mode ThinFilm V2 100W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    else 
            figure(4)
            subplot(2,4,k-7);
            h = plot(fitresult,freq,amp,'o');
            title([titles_half(k-7) linewidth], 'FontSize', 14) 
%             sgtitle('Halfwave Mode ThinFilm V2 100W')
            suptitle('Halfwave Mode ThinFilm V2 100W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    end
    xlabel('Frequency (Hz)'); ylabel('|S_{21}|') 
    set(h,'LineWidth',2); set(gca,'YScale','log') % Show |S21| in log scale
    
end




%% Thin Film V2 150 W %%

directories = {
    '/data/ThinFilm_V2_150W_0.10Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_0.25Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_0.50Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_1.00Cf/quarterwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_0.10Cf/halfwave_-50dBm.csv'
    '/data/ThinFilm_V2_150W_0.25Cf/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_0.50Cf/halfwave_-60dBm.csv'
    '/data/ThinFilm_V2_150W_1.00Cf/halfwave_-60dBm.csv'
    };

titles_quarter = {
    '0.10 Cf (DCtap 0.5pF)' '0.25 Cf (DCtap 1.25pF)' '0.50 Cf (DCtap 2.5pF)' '1.00 Cf (DCtap 5pF)' 
    };
titles_half = {
    '0.10 Cf' '0.25 Cf' '0.50 Cf' '1.00 Cf' 
    };

for k=1:length(directories)
    dir = [maindir, directories{k}];
    data = dlmread(dir,'',3,0);
    freq = data(:,1);
    amp = data(:,2);  % |S21|, amplitude ratio (linear scale)
    [a, b] = max(amp);
    startPoints = [0.05e6 freq(b) 80 0.8*pi max(amp) 1e6   ];
    [fitresult, linewidth] = fanofit(freq,amp,startPoints,lowerPoints,upperPoints);
    if k<5
            figure(5)
            subplot(2,2,k);
            h = plot(fitresult,freq,amp,'o');
            title([titles_quarter(k) linewidth], 'FontSize', 14) 
%             sgtitle('Quarterwave Mode ThinFilm V2 150W')
            suptitle('Quarterwave Mode ThinFilm V2 150W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    else 
            figure(6)
            subplot(2,2,k-4);
            h = plot(fitresult,freq,amp,'o');
            title([titles_half(k-4) linewidth], 'FontSize', 14) 
%             sgtitle('Halfwave Mode ThinFilm V2 150W')
            suptitle('Halfwave Mode ThinFilm V2 150W') % Use sgtitle if suptitle gives error (depends on Matlab version)
    end
    xlabel('Frequency (Hz)'); ylabel('|S_{21}|') 
    set(h,'LineWidth',2); set(gca,'YScale','log') % Show |S21| in log scale
    
end

%% Planar Filters %%

% These data are taken in a dilution refrigerator
directories = {
    '/data/Planar_NoFilters_WirebondSurgery/quarterwave_-40dBm.dat'
    '/data/Planar_Filters_1.00Cf_0.50Lf/quarterwave_-40dBm.dat'
    '/data/Planar_Filters_1.00Cf_0.50Lf_WirebondSurgery/quarterwave_-40dBm.dat'
    '/data/Planar_Filters_1.00Cf_1.00Lf/quarterwave_-40dBm.dat'    
    '/data/Planar_Filters_1.00Cf_1.00Lf_WirebondSurgery/quarterwave_-40dBm.dat' 
    '/data/Planar_NoFilters_WirebondSurgery/halfwave_-40dBm.dat'
    '/data/Planar_Filters_1.00Cf_0.50Lf_WirebondSurgery/halfwave_-40dBm.dat'   
    '/data/Planar_Filters_1.00Cf_1.00Lf_WirebondSurgery/halfwave_-40dBm.dat' 
};

titles = {
    'Planar NoFilters WirebondSurgery' 
    'Planar Filters 1 Cf 0.5 Lf' 
    'Planar Filters 1 Cf 0.5 Lf WirebondSurgery' 
    'Planar Filters 1 Cf 1 Lf' 
    'Planar Filters 1 Cf 1 Lf WirebondSurgery'
    };

for k=1:length(directories)
    dir = [maindir, directories{k}];
    data = dlmread(dir,'',3,0);
    freq = data(:,1);
    amp = data(:,4);  % |S21|, amplitude ratio (linear scale)
    pow = amp.^2;   % |S21|^2, power ratio (linear scale)
    [a, b] = max(pow);
    pow = pow/a; % Normalize for the fit
    startPoints = [freq(b) max(pow) 1e6 0   ];
    lowerPoints = [0 0 0 0];
    upperPoints = [Inf Inf Inf Inf];
    [fitresult, linewidth] = lorentzfit(freq,pow,startPoints,lowerPoints,upperPoints);
    if k<6
            figure(7)
            subplot(2,3,k);
            h = plot(fitresult,freq,pow,'o');
            title([titles(k) linewidth], 'FontSize', 14) 
%             sgtitle('Quarterwave Planar Filters')
            suptitle('Quarterwave Planar Filters') % Use sgtitle if suptitle gives error (depends on Matlab version)
    else 
           figure(8)
            subplot(2,2,k-5);
            h = plot(fitresult,freq,pow,'o');
            title([titles(2*(k-6)+1) linewidth], 'FontSize', 14) 
%             sgtitle('Halfwave Planar Filters')
            suptitle('Halfwave Planar Filters') % Use sgtitle if suptitle gives error (depends on Matlab version)
    end
    xlabel('Frequency (Hz)'); ylabel('|S_{21}|^2') 
    set(h,'LineWidth',2); set(gca,'YScale','log') % Show |S21|^2 in log scale
end


%% Planar Filters - Fewpads and Onepad Varations%%

% The dat-files are from measurements in a dilution refrigerator
directories = {
    '/data/Planar_Onepad_0.50Cf/quarterwave_-40dBm.csv'
    '/data/Planar_Onepad_1.00Cf/quarterwave_-40dBm.dat'
    '/data/Planar_Onepad_1.00Cf_LongNarrowLines/quarterwave_-60dBm.csv'
    '/data/Planar_Fewpads_WithAddedCrossbonds/quarterwave_-60dBm.csv'
    '/data/Planar_Fewpads_WithoutAddedCrossbonds/quarterwave_-50dBm.csv'
    '/data/Planar_Onepad_0.50Cf/halfwave_-60dBm.csv'
    '/data/Planar_Onepad_1.00Cf/halfwave_-40dBm.dat'
    '/data/Planar_Onepad_1.00Cf_LongNarrowLines/halfwave_-60dBm.csv'
    '/data/Planar_Fewpads_WithAddedCrossbonds/halfwave_-60dBm.csv'
    };

titles = {
    'Onepad 0.50 Cf' 'Onepad 1.00 Cf' 'Onepad 1.00 Cf LongNarrowLines' 'Fewpads WithAddedCrossbonds' 'Fewpads WithoutAddedCrossbonds' 
    };

for k=1:length(directories)
    dir = [maindir, directories{k}];
    data = dlmread(dir,'',3,0);
    freq = data(:,1);
    if k == 2 || k == 7
        amp = data(:,4);  % |S21|, amplitude ratio (linear scale)
    else
        amp = sqrt(data(:,2).^2+data(:,3).^2);  % |S21|, amplitude ratio (linear scale)
    end
    pow = amp.^2;  % |S21|^2, power ratio (linear scale)
    [a, b] = max(pow);
    pow = pow/a; % Normalize for the fit
    startPoints = [freq(b) max(pow) 2e6 0   ];
    lowerPoints = [0 0 0 0];
    upperPoints = [Inf Inf Inf Inf];
    [fitresult, linewidth] = lorentzfit(freq,pow,startPoints,lowerPoints,upperPoints);
    if k<6
            figure(9)
            subplot(2,3,k);
            h = plot(fitresult,freq,pow,'o');
            title([titles(k) linewidth], 'FontSize', 14) 
%             sgtitle('Quarterwave Planar Variations')
            suptitle('Quarterwave Planar Variations') % Use sgtitle if suptitle gives error (depends on Matlab version)
    else 
            figure(10)
            subplot(2,2,k-5);
            h = plot(fitresult,freq,pow,'o');
            title([titles(k-5) linewidth], 'FontSize', 14) 
%             sgtitle('Halfwave Planar Variations')
            suptitle('Halfwave Planar Variations') % Use sgtitle if suptitle gives error (depends on Matlab version)
    end
    xlabel('Frequency (Hz)'); ylabel('|S_{21}|^2') 
    set(h,'LineWidth',2); set(gca,'YScale','log') % Show |S21|^2 in log scale
end


